<?php
/**
 * Special Day options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */
// Add Special Day section
$wp_customize->add_section( 'yummy_pro_special_day_section', array(
	'title'             => esc_html__( 'Special Day Section','yummy-pro' ),
	'description'       => esc_html__( 'Special Day options.', 'yummy-pro' ),
	'panel'             => 'yummy_pro_sections_panel',
) );
/**
 * Special Day Options
 */
// Enable Special Day.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_special_day]', array(
	'default'           => $options['enable_special_day'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_special_day]', array(
	'label'             => esc_html__( 'Enable Special Day Section', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'checkbox'
) );

/**
 * Special Day background image setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_background_image]', array(
	'default'           => $options['special_day_background_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[special_day_background_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_special_day_section',
		'active_callback'	=> 'yummy_pro_is_special_day_section_active',
) ) );

/**
 * Special Day Header Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_left_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[special_day_left_label]', array(
	'label'           	=> __( 'Left Note Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_day_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_special_day_section_active',
) ) );

/**
 * Special Day Header type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_left_type]', array(
	'default'           => $options['special_day_left_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_left_type]', array(
	'active_callback'	=> 'yummy_pro_is_special_day_section_active',
	'label'             => esc_html__( 'Left Note Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'choices'			=> yummy_pro_special_day_left_type_options(),
	'type'				=> 'select'
) );

/**
 * Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_left_note]', array(
	'default'           => $options['special_day_left_note'],
	'sanitize_callback' => 'yummy_pro_santize_special_tags',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_left_note]', array(
	'active_callback'	=> 'yummy_pro_special_day_left_type_custom',
	'label'             => esc_html__( 'Left Note', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'textarea',
	'input_attrs'		=> array(
		'placeholder'	=> sprintf( esc_html__( '%1$sRock%2$s %3$sFriday%4$s %5$sWe cook special in%6$s %7$sSpecial day%8$s', 'yummy-pro' ), '<h2>', '</h2>', '<span>', '</span>', '<p>', '</p>', '<h3>', '</h3>'  ),
		),
) );

/**
 * left Button link title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_left_btn_title]', array(
	'default'			=> $options['special_day_left_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_left_btn_title]', array(
	'active_callback'	=> 'yummy_pro_special_day_left_type_custom',
	'label'             => esc_html__( 'Button Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'text'
) );

/**
 * left button link Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_left_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_left_btn_link]', array(
	'active_callback'	=> 'yummy_pro_special_day_left_type_custom',
	'label'             => esc_html__( 'Button Link', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'url'
) );

/**
 * Special Day hr setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[special_day_hr]',
	array(
		'section'         => 'yummy_pro_special_day_section',
		'active_callback' => 'yummy_pro_is_special_day_section_active',
		'type'			  => 'hr'
) ) );

/**
 * Special Day right Content Label.
 */ 
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[special_day_right_label]', array(
	'label'           	=> __( 'Right Content Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_day_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_special_day_section_active',
) ) );

/**
 * Special Day content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_note_type]', array(
	'default'           => $options['special_day_right_note_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_note_type]', array(
	'active_callback'	=> 'yummy_pro_is_special_day_section_active',
	'label'             => esc_html__( 'Right Note Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'choices'			=> yummy_pro_special_day_right_note_type_options(),
	'type'				=> 'select'
) );

/**
 * Special Day right note content type post options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_note_post]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_note_post]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_note_type_post',
	'label'             => esc_html__( 'Input Post ID', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

/**
 * Page right Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_note_page]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_note_page]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_note_type_page',
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'dropdown-pages'
) );

/**
 * Custom right Content Type Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_note_title]', array(
	'default'			=> $options['special_day_right_note_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_note_title]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_note_type_custom',
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'text'
) );

/**
 * Custom right Content Type Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_note_description]', array(
	'default'			=> $options['special_day_right_note_description'],
	'sanitize_callback' => 'esc_textarea',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_note_description]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_note_type_custom',
	'label'             => esc_html__( 'Description', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'textarea'
) );

/**
 * Special Day content type options.
 *
 * Options are similar to special item therefore the choice function has been reused.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_type]', array(
	'default'           => $options['special_day_right_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_type]', array(
	'active_callback'	=> 'yummy_pro_is_special_day_section_active',
	'label'             => esc_html__( 'Posts Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'choices'			=> yummy_pro_special_item_content_type_options(),
	'type'				=> 'select'
) );

/**
 * No of Contents Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_right_count]', array(
	'default'			=> $options['special_day_right_count'],
	'sanitize_callback' => 'yummy_pro_sanitize_number_range',
	'validate_callback' => 'yummy_pro_validate_special_day_count',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_right_count]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_count',
	'label'             => esc_html__( 'No. of Posts', 'yummy-pro' ),
	'description'       => esc_html__( 'Max posts: 10', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style'	=> 'width:100px',
		),
) );

/**
 * Post right Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_content_post]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_content_post]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_type_post',
	'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. posts allowed is 10. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'text'
) );

/**
 * Category Content Type Options
 */
// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_content_category]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[special_day_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'yummy-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'yummy-pro' ),
	'section'         => 'yummy_pro_special_day_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'yummy_pro_special_day_right_type_category',
) ) );

/**
 * Woocommerce Product Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_content_woo_product]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[special_day_content_woo_product]', array(
	'active_callback'	=> 'yummy_pro_special_day_right_type_woo_product',
	'label'             => esc_html__( 'Input WooCommerce Product Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. products allowed is 10. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_special_day_section',
	'type'				=> 'text'
) );

/**
 * Woocommerce Product Category Content Type Options
 */
// Show category type setting and control
$wp_customize->add_setting( 'yummy_pro_theme_options[special_day_content_woo_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Yummy_Pro_Dropdown_Single_Category_Control( $wp_customize, 'yummy_pro_theme_options[special_day_content_woo_category]', array(
	'label'           	=> esc_html__( 'Select WooCommerce Product Category', 'yummy-pro' ),
	'description'     	=> esc_html__( 'Latest products from selected category will be shown.', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_special_day_section',
	'taxonomy'		  	=> 'product_cat',
	'type'			  	=> 'dropdown-category',
	'active_callback' 	=> 'yummy_pro_special_day_right_type_woo_category',
) ) );