<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Yummy Pro
 * @since Yummy Pro 1.0
 */

$options = yummy_pro_get_theme_options();


if ( ! function_exists( 'yummy_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Yummy Pro 1.0
	 */
	function yummy_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'yummy_pro_doctype', 'yummy_pro_doctype', 10 );


if ( ! function_exists( 'yummy_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'yummy_pro_before_wp_head', 'yummy_pro_head', 10 );

if ( ! function_exists( 'yummy_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'yummy-pro' ); ?></a>

		<?php
	}
endif;

add_action( 'yummy_pro_page_start_action', 'yummy_pro_page_start', 10 );

if ( ! function_exists( 'yummy_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'yummy_pro_page_end_action', 'yummy_pro_page_end', 10 );

if ( ! function_exists( 'yummy_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_header_start() {
		?>
		<header id="masthead" class="site-header sticky" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'yummy_pro_header_action', 'yummy_pro_header_start', 10 );

if ( ! function_exists( 'yummy_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_site_branding() {
		$options = yummy_pro_get_theme_options();
		$sitetitle = get_bloginfo( 'name' );
		$sitedescription = get_bloginfo( 'description', 'display' );
		if( has_custom_logo() || display_header_text() ) : ?>
			<div class="site-branding">
	            <?php if ( has_custom_logo() && true === $options['site_logo_enable'] ) : ?>
					<div class="site-logo">
			        	<?php the_custom_logo(); ?>
	          		</div><!-- end .site-logo -->
			    <?php endif;
			    if ( display_header_text() && ( true === $options['site_title_enable'] || true === $options['site_description_enable'] ) ) { ?>
		          	<div class="site-branding-text">
						<?php if ( true === $options['site_title_enable'] ) :
							if ( is_front_page() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
							endif;
						endif;
						if ( true === $options['site_description_enable'] ) :
							if ( $sitedescription || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $sitedescription ); /* WPCS: xss ok. */ ?></p>
							<?php
							endif;
						endif; ?>
					</div>
				<?php } ?>
			</div><!-- .site-branding -->
		<?php
		endif;
	}
endif;
add_action( 'yummy_pro_header_action', 'yummy_pro_site_branding', 20 );

if ( ! function_exists( 'yummy_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_site_navigation() {
		$options = yummy_pro_get_theme_options();

		if( ! $options['disable_primary_menu'] ) { ?>
			<nav id="site-navigation" class="main-navigation" role="navigation">
				<button class="menu-toggle">
					<span class="icon-bar"></span>
	            	<span class="icon-bar"></span>
	            	<span class="icon-bar"></span>
	            </button>
				<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu', 'container' => false ) ); ?>
			</nav><!-- #site-navigation -->
		<?php
		}
	}
endif;
add_action( 'yummy_pro_header_action', 'yummy_pro_site_navigation', 30 );


if ( ! function_exists( 'yummy_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_header_end() {
		?>
			</div><!--.wrapper-->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'yummy_pro_header_action', 'yummy_pro_header_end', 50 );

if ( ! function_exists( 'yummy_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'yummy_pro_content_start_action', 'yummy_pro_content_start', 10 );

if ( ! function_exists( 'yummy_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'yummy_pro_content_end_action', 'yummy_pro_content_end', 10 );

if ( ! function_exists( 'yummy_pro_footer_start' ) ) :
	/**
	 * End div id #content
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_start() {
		$footer_sidebar_data = yummy_pro_footer_sidebar_class();
		$class               = $footer_sidebar_data['class'];
		?>
		<footer id="colophon" class="site-footer col-<?php echo esc_attr( $class );?>" role="contentinfo">
		<?php
	}
endif;
add_action( 'yummy_pro_footer_start', 'yummy_pro_footer_start', 10 );


if ( ! function_exists( 'yummy_pro_footer_widgets' ) ) :
	/**
	 * Footer widgets
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_widgets() {
		$options = yummy_pro_get_theme_options();
		$footer_sidebar_data = yummy_pro_footer_sidebar_class();
		$active_id           = $footer_sidebar_data['active_id'];
		$footer_background_image = $options['footer_background_image'];
		$enable_footer_section = $options['enable_footer'];

		if ( $enable_footer_section == 'static-front-page' ) {
			if ( ! is_front_page() )
				return;
		}

		if ( empty( $active_id ) ) {
			return;
		} ?>
		<div class="footer-wrapper widget-area page-section" style="background-image: url('<?php echo esc_url( $footer_background_image ); ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
			<div class="black-overlay"></div>
        	<div class="wrapper">
        		<div class="row">
			      	<?php for ( $i=0; $i < count( $active_id ); $i++ ) { ?>

					<div class="column-wrapper">
			      		<?php 
			      		if ( is_active_sidebar( 'footer-'.absint( $active_id[ $i ] ).'' ) ){
			      			dynamic_sidebar( 'footer-'.absint( $active_id[ $i ] ).'' );
			      		}
			      		?>
			      	</div>
			      	<?php } ?>
		        </div><!-- end .row -->
		    </div>
	    </div>
		<?php
	}
endif;
add_action( 'yummy_pro_footer', 'yummy_pro_footer_widgets', 10 );

if ( ! function_exists( 'yummy_pro_footer_bottom_start' ) ) :
	/**
	 * start div class .bottom-footer
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_bottom_start() { 
		$options = yummy_pro_get_theme_options();
		$copyright_background_image = $options['copyright_background_image']; ?>
		<div class="bottom-footer page-section" style="background-image: url('<?php echo esc_url( $copyright_background_image ); ?>');">
        	<div class="wrapper">
	<?php }
endif;
add_action( 'yummy_pro_footer', 'yummy_pro_footer_bottom_start', 11 );

if ( ! function_exists( 'yummy_pro_footer_social_menu' ) ) :
	/**
	 * social link
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_social_menu() { 
		if ( has_nav_menu( 'social' ) ) : ?> 
			<div class="social-link">
	            <?php wp_nav_menu( array( 'theme_location' => 'social', 'container' => 'ul', 'menu_class' => 'social-icons' ) ); ?>
	        </div><!--.social-link-->
		<?php endif;
	}
endif;
add_action( 'yummy_pro_footer', 'yummy_pro_footer_social_menu', 15 );

if ( ! function_exists( 'yummy_pro_copyright' ) ) :
	/**
	 * End div class .site-info
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_copyright() { 
		$options = yummy_pro_get_theme_options();

		$search = array( '[the-year]', '[site-link]' );

        $replace = array(  date( esc_html_x( 'Y', 'yearly archives date format',  'yummy-pro' ) ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text 	= $options['copyright_text'];

		$powered_by_text 	= $options['powered_by'];
		
		if ( ! empty( $copyright_text ) || ! empty( $powered_by_text ) ) :  ?>
	    <div class="site-info">
	    	<span class="copyright"><?php echo wp_kses_post( $copyright_text ); ?></span>
	    	<span class="powered">
	    		<?php 
	    		echo wp_kses_post( $powered_by_text );
	    		if ( function_exists( 'the_privacy_policy_link' ) ) {
				    the_privacy_policy_link( ' | ' );
				}
	    		?>
	    	</span>
	    </div><!-- end .site-info -->  	
	<?php
		endif;
	}
endif;
add_action( 'yummy_pro_footer', 'yummy_pro_copyright', 20 );

if ( ! function_exists( 'yummy_pro_footer_bottom_end' ) ) :
	/**
	 * end div class .bottom-footer
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_bottom_end() { ?>
			</div><!--.wrapper-->
    	</div><!-- .bottom-footer -->
	<?php }
endif;
add_action( 'yummy_pro_footer', 'yummy_pro_footer_bottom_end', 25 );

if ( ! function_exists( 'yummy_pro_footer_end' ) ) :
	/**
	 * End footer id #colophon
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_footer_end() {
		?>
        </footer><!-- end .site-footer -->
		<?php
	}
endif;
add_action( 'yummy_pro_footer_end', 'yummy_pro_footer_end', 100 );

if ( ! function_exists( 'yummy_pro_back_to_top' ) ) :
	/**
	 * Back to top class .backtotop
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_back_to_top() {
		$options = yummy_pro_get_theme_options();
		if ( $options['scroll_top_visible'] ) : ?>
        	<div class="backtotop"><i class="fa fa-angle-up"></i></div><!--end .backtotop-->
		<?php endif;
	}
endif;
add_action( 'yummy_pro_footer_end', 'yummy_pro_back_to_top', 110 );

if ( ! function_exists( 'yummy_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Yummy Pro 1.0
	 *
	 */
	function yummy_pro_loader() {
		$options = yummy_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
	         <div class="loader-container">
         		<i class="fa <?php echo esc_attr( $options['loader_icon'] );?> fa-spin"></i>
	         </div>
	     	</div><!-- end loader -->
		<?php }
	}
endif;
add_action( 'yummy_pro_before_header', 'yummy_pro_loader', 10 );


if ( ! function_exists( 'yummy_pro_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since Yummy Pro 1.0
	 */
	function yummy_pro_add_breadcrumb() {
		$options = yummy_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		// Bail if Home Page.
		if ( is_front_page() && ! is_home() ) {
			return;
		}

		echo '<div class="container">';
				/**
				 * yummy_pro_simple_breadcrumb hook
				 *
				 * @hooked yummy_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'yummy_pro_simple_breadcrumb' );
		echo '<div class="icon-scroll"></div>
        </div><!--.container--> ';
		return;
	}

endif;
add_action( 'yummy_pro_add_breadcrumb', 'yummy_pro_add_breadcrumb' , 10 );